@@ -215,6 +215,7 @@ struct _HNAppSwitcherPrivate
   guint is_thumbable : 1;
   gboolean force_thumb : 1;
   guint was_thumbable : 1;
+  gboolean is_fullscreen;
 
   guint menu_button_timeout;
 
@@ -644,8 +645,12 @@ main_menu_keypress_cb (GtkWidget * menu, GdkEventKey *event,
     }
     else
     {
-      g_debug ("%s: %d, hd_wm_activate (HN_TN_ACTIVATE_KEY_FOCUS);",__FILE__,__LINE__);
-      gtk_widget_grab_focus (app_switcher->priv->main_button);
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (app_switcher->priv->main_button), TRUE);
+	    
+      GdkWindow *window = gtk_widget_get_parent_window (app_switcher->priv->main_button);
+
+      gtk_widget_grab_focus (GTK_WIDGET (app_switcher->priv->main_button));
+      hd_wm_activate_window (HD_TN_ACTIVATE_KEY_FOCUS,window);
     }
         
     return TRUE;
@@ -728,6 +733,7 @@ main_menu_position_func (GtkMenu  *menu,
 			 gboolean *push_in,
 			 gpointer  data)
 {
+  HNAppSwitcher *app_switcher = HN_APP_SWITCHER (data);	
   GtkRequisition req;
   GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (menu));
   gint menu_height = 0;
@@ -757,7 +763,7 @@ main_menu_position_func (GtkMenu  *menu,
   menu_height = req.height;
   main_height = gdk_screen_get_height (screen);
 
-  if (hd_wm_fullscreen_mode ())
+  if (app_switcher->priv->is_fullscreen)
   {
     *x = 0;
     *y = MAX (0, (main_height - menu_height));
@@ -886,7 +892,7 @@ main_menu_button_keypress_cb (GtkWidget     *toggle,
   if (event->keyval == GDK_Left || event->keyval == GDK_KP_Left)
   {
     g_debug ("%s: %d, hd_wm_activate (HN_TN_ACTIVATE_LAST_APP_WINDOW);",__FILE__,__LINE__);
-  }
+  }			  
   
   return FALSE;
 }
@@ -1205,6 +1211,12 @@ create_app_button (HNAppSwitcher *app_switcher,
   return priv->buttons[pos];
 }
 
+static void 
+hn_app_switcher_track_fullscreen_cb (HDWM *hdwm, gboolean fullscreen, HNAppSwitcher *app_switcher)
+{
+  app_switcher->priv->is_fullscreen = fullscreen;
+}	
+
 static void
 hn_app_switcher_build (HNAppSwitcher *app_switcher)
 {
@@ -1275,6 +1287,11 @@ hn_app_switcher_build (HNAppSwitcher *app_switcher)
 		    G_CALLBACK (hn_app_switcher_close_application_dialog),
 		    NULL);
 
+  g_signal_connect (app_switcher->hdwm,
+		    "fullscreen",
+		    G_CALLBACK (hn_app_switcher_track_fullscreen_cb),
+		    (gpointer)app_switcher);
+
   g_signal_connect (app_switcher,
 		    "notify::orientation",
 		    G_CALLBACK (hn_app_switcher_orientation_changed_cb),
@@ -2126,6 +2143,7 @@ hn_app_switcher_init (HNAppSwitcher *app_switcher)
   
   app_switcher->priv->buttons_group = NULL;
 
+  app_switcher->priv->is_fullscreen = 
   app_switcher->priv->force_thumb = FALSE;
 
   gtk_widget_set_name (GTK_WIDGET (app_switcher), AS_BOX_NAME);
